@@ -46,8 +46,10 @@ test_that("d3-jetpack on latest release", {
 
   expect_identical(
     jetpack$version,
-    jsonlite::fromJSON(
-      "https://unpkg.com/d3-jetpack/package.json"
-    )$version
+    gsub(
+      x=github::get.latest.release("gka","d3-jetpack")$content$tag_name,
+      pattern="v",
+      replacement=""
+    )
   )
 })
